summaryrefslogtreecommitdiffstats
path: root/chrome/browser/io_thread.h
diff options
context:
space:
mode:
authormattm@chromium.org <mattm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-20 22:42:29 +0000
committermattm@chromium.org <mattm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-20 22:42:29 +0000
commit9c4eff26e509149d2133268af7744a5cdb079dd1 (patch)
tree37f5ddc3dee1ed87d40a9e8ff6dce25778cfb1e0 /chrome/browser/io_thread.h
parent4a210ecd52feb4f61969f329c5bd10b5746c6e2b (diff)
downloadchromium_src-9c4eff26e509149d2133268af7744a5cdb079dd1.zip
chromium_src-9c4eff26e509149d2133268af7744a5cdb079dd1.tar.gz
chromium_src-9c4eff26e509149d2133268af7744a5cdb079dd1.tar.bz2
Change Origin bound certs -> Domain bound certs.
BUG=115348 TEST=unit tests, manually checked 'Origin Bound Certs' contents after browsing TBR=jam@chromium.org,willchan@chromium.org Review URL: https://chromiumcodereview.appspot.com/9617039 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@127817 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/io_thread.h')
-rw-r--r--chrome/browser/io_thread.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/io_thread.h b/chrome/browser/io_thread.h
index 3e3bbdd..d651faa 100644
--- a/chrome/browser/io_thread.h
+++ b/chrome/browser/io_thread.h
@@ -35,7 +35,7 @@ class HttpAuthHandlerFactory;
class HttpServerProperties;
class HttpTransactionFactory;
class NetworkDelegate;
-class OriginBoundCertService;
+class ServerBoundCertService;
class ProxyConfigService;
class ProxyService;
class SdchManager;
@@ -93,10 +93,10 @@ class IOThread : public content::BrowserThreadDelegate {
scoped_ptr<net::HttpTransactionFactory> system_http_transaction_factory;
scoped_ptr<net::FtpTransactionFactory> system_ftp_transaction_factory;
scoped_refptr<net::URLRequestContext> system_request_context;
// |system_cookie_store| and |system_origin_bound_cert_service| are shared
// between |proxy_script_fetcher_context| and |system_request_context|.
scoped_refptr<net::CookieStore> system_cookie_store;
- scoped_ptr<net::OriginBoundCertService> system_origin_bound_cert_service;
+ scoped_ptr<net::ServerBoundCertService> system_server_bound_cert_service;
scoped_refptr<ExtensionEventRouterForwarder>
extension_event_router_forwarder;
};
@@ -93,10 +93,10 @@ class IOThread : public content::BrowserThreadDelegate {
scoped_ptr<net::FtpTransactionFactory> system_ftp_transaction_factory;
scoped_refptr<net::URLRequestContext> system_request_context;
- // |system_cookie_store| and |system_origin_bound_cert_service| are shared
+ // |system_cookie_store| and |system_server_bound_cert_service| are shared
// between |proxy_script_fetcher_context| and |system_request_context|.
scoped_refptr<net::CookieStore> system_cookie_store;